Author: Guillaume Potier
Description: Parsley is a dead simple javascript form validation, powerful and UX aware
Keywords: javascript form validation, javascript, form, validation, jquery, plungin, html, UX

### Parsley.js

# Javascript forms validation.
Powerful, UX aware & Dead simple.

Never write a single javascript line anymore to validate your forms FrontEnd. Parsley will do that for you – and do it right –, thanks to its powerful DOM-API !

See documentation & examples

- Download
- Version 1.2.4

#### Super #UX focused

User Experience matters. A lot. Parsley is totally aware of that, and is designed to help your users and not bother or frustrate them.

See demonstration.

#### Super light

Less than 800 lines. Less than 12k minified.
Works with jQuery and Zepto (with data and fx_methods added).

Get Latest version.

#### Super free

Parsley is open source, MIT licensed, and developed to help everyone. It will stay that way.

See License.

#### Super configurable

Like no other javascript library, Parsley has a full support for #UX concerns and detailed options. Override almost every Parsley default behaviors to fit your exact needs.

See documentation.

#### Super simple

Want to validate a form? Just write it in English with the awesome Parsley DOM-API using jQuery data API.

See documentation.

#### Super reliable

Form validation is important, #UX is critical. Parsley is shipped almost bug free to help you with that.

See Parsley Test Suite.